pub struct AttestationParams {
pub user_data: Option<Vec<u8>>,
pub nonce: Option<Vec<u8>>,
pub public_key: Option<Vec<u8>>,
}Expand description
Parameters for requesting an attestation document from the Nitro Security Module.
Fields
user_data: Option<Vec<u8>>Optional user data to include in the attestation document (e.g. SHA-256 hash of TLS cert).
nonce: Option<Vec<u8>>Optional cryptographic nonce to prevent replay attacks.
public_key: Option<Vec<u8>>Optional public key (DER-encoded) for cryptographic sealing or key exchange.
Implementations
Sourceimpl AttestationParams
Builder-style setters and accessors for the attestation parameters.
impl AttestationParams
Builder-style setters and accessors for the attestation parameters.
Sourcepub fn with_user_data(self, data: impl Into<Vec<u8>>) -> Self
pub fn with_user_data(self, data: impl Into<Vec<u8>>) -> Self
Sets user data bytes.
Sourcepub fn with_user_data_hash(self, data: &[u8]) -> Self
pub fn with_user_data_hash(self, data: &[u8]) -> Self
Computes the SHA-256 hash of the input data (such as a DER-encoded certificate)
and sets it as the user_data field for Remote Attestation TLS (RA-TLS).
Sourcepub fn with_nonce(self, nonce: impl Into<Vec<u8>>) -> Self
pub fn with_nonce(self, nonce: impl Into<Vec<u8>>) -> Self
Sets the cryptographic nonce.
Sourcepub fn with_public_key(self, public_key: impl Into<Vec<u8>>) -> Self
pub fn with_public_key(self, public_key: impl Into<Vec<u8>>) -> Self
Sets the DER-encoded public key.
Sourcepub fn public_key(&self) -> Option<&[u8]>
pub fn public_key(&self) -> Option<&[u8]>
Returns a reference to the public key, if set.