Network services of the RA-TLS stack over QUIC / HTTP/3 (RFC 9114), plus the RA-TLS identity and attestation request parameters they share.
Modules
- client
- TTKServer HTTP/3 (QUIC) Client implementation.
- router
- HTTP routes of the RA-TLS server, served over HTTP/3 by
super::server: - server
- RATS (RFC 9334) role mapping for this server:
Structs
- Attestation
Params - Parameters for requesting an attestation document from the Nitro Security Module.
Functions
- generate_
identity - Generates a self-signed ephemeral TLS certificate and private key for Remote Attestation TLS (RA-TLS).