TtkClient

Struct TtkClient 

pub struct TtkClient { /* private fields */ }
HTTP/3 client for communicating with TTKServer over QUIC.

Implementations

Source

impl TtkClient

Connecting to the server and issuing requests.

pub async fn connect( server_addr: SocketAddr, server_name: &str, ) -> Result<Self, Box<dyn Error + Send + Sync>>

Connect to the TTKServer at the specified server_addr with the given SNI server_name, accepting only genuine AWS Nitro attestation (see EnclaveCertVerifier::new).

pub async fn connect_with_verifier( server_addr: SocketAddr, server_name: &str, verifier: EnclaveCertVerifier, ) -> Result<Self, Box<dyn Error + Send + Sync>>

Connect to the TTKServer using a custom attestation verifier policy.

pub fn server_addr(&self) -> SocketAddr

Return the server address this client is connected to.

pub fn server_name(&self) -> &str

Return the SNI server name configured for this client.

pub fn peer_cert(&self) -> Option<&CertificateDer<'static>>

Retrieve the peer’s certificate DER bytes if captured.

pub fn peer_cert_sha256(&self) -> Option<[u8; 32]>

Retrieve the SHA-256 digest of the peer certificate.

pub fn peer_cert_sha256_hex(&self) -> Option<String>

Retrieve the SHA-256 digest of the peer certificate as a hex string.

pub async fn get( &mut self, path: &str, ) -> Result<ClientResponse, Box<dyn Error + Send + Sync>>

Send an HTTP/3 GET request to the specified path.

pub async fn post( &mut self, path: &str, body: &[u8], ) -> Result<ClientResponse, Box<dyn Error + Send + Sync>>

Send an HTTP/3 POST request with the given body to the specified path.

pub async fn send( &mut self, req: Request<()>, payload: Option<&[u8]>, ) -> Result<ClientResponse, Box<dyn Error + Send + Sync>>

Send an HTTP/3 request with an optional payload and receive the response.

pub async fn close(self) -> Result<(), Box<dyn Error + Send + Sync>>

Close the client and wait for underlying QUIC streams and driver to settle.